@@ -1220,23 +1220,9 @@ static void fn_rndpar(void) {
 static void fn_sgn(void) {
   (*factor_table[*basicvars.current])();
   if (GET_TOPITEM == STACK_INT || GET_TOPITEM == STACK_UINT8 || GET_TOPITEM == STACK_INT64) {
-    int64 value = pop_anyint();
-    if (value>0) {
-      push_int(1);
-    } else if (value == 0) {
-      push_int(0);
-    } else {
-      push_int(-1);
-    }
+    push_int(sgni(pop_anyint()));
   } else if (GET_TOPITEM == STACK_FLOAT) {
-    floatvalue = pop_float();
-    if (floatvalue>0.0) {
-      push_int(1);
-    } else if (floatvalue == 0.0) {
-      push_int(0);
-    } else {
-      push_int(-1);
-    }
+    push_int(sgnf(pop_float()));
   } else error(ERR_TYPENUM);
 }
 
@@ -1281,7 +1267,7 @@ static void fn_str(void) {
       int32 format, numdigits;
       char *fmt;
       format = basicvars.staticvars[ATPERCENT].varentry.varinteger;
-      if ((format & STRUSE) == 0) format = STRFORMAT;	/* Use predefined format, not @% */
+      if ((format & STRUSECHK) == 0) format = STRFORMAT;	/* Use predefined format, not @% */
       switch ((format>>2*BYTESHIFT) & BYTEMASK) {	/* Determine format of floating point values */
       case FORMAT_E:
        fmt = "%.*E";
@@ -1760,7 +1746,8 @@ static void fn_sysfn(void) {
   basicstring descriptor;
   stackitem stringtype;
   char *tmpstring;
-  size_t inregs[MAXSYSPARMS], outregs[MAXSYSPARMS];
+  sysparm inregs[MAXSYSPARMS];
+  size_t outregs[MAXSYSPARMS];
   (*factor_table[*basicvars.current])();
   stringtype = GET_TOPITEM;
   if (stringtype == STACK_STRING || stringtype == STACK_STRTEMP) {
@@ -1768,7 +1755,7 @@ static void fn_sysfn(void) {
     tmpstring = strdup(descriptor.stringaddr);
     if (tmpstring == NULL) error(ERR_BROKEN, __LINE__, "functions");
     tmpstring[descriptor.stringlen]='\0';
-    inregs[1] = (size_t)tmpstring;
+    inregs[1].i = (size_t)tmpstring;
     mos_sys(SWI_OS_SWINumberFromString+XBIT, inregs, outregs, 0);
     push_varyint(outregs[0]);
     free(tmpstring);
