@@ -120,6 +120,10 @@
 #include "inkey.h"
 #include "mos.h"
 
+#ifdef TARGET_SUNOS
+#include <sys/filio.h>
+#endif
+
 #ifdef TARGET_RISCOS
 /* New keyboard routines */
 /* --------------------- */
@@ -348,7 +352,9 @@ int32 kbd_readline(char *buffer, int32 length, int32 chars) {
 #endif
 
 #ifdef TARGET_UNIX
-// #include <sys/time.h>
+#ifdef TARGET_MINIX
+#include <sys/time.h>
+#endif /* TARGET_MINIX */
 // #include <sys/types.h>
 #include <errno.h>
 // #include <unistd.h>
@@ -356,7 +362,7 @@ int32 kbd_readline(char *buffer, int32 length, int32 chars) {
 #include <termios.h>
 // Move these later
 static struct termios origtty;  /* Copy of original keyboard parameters */
-#endif
+#endif /* TARGET_UNIX */
 
 #ifdef USE_SDL
 #include "SDL.h"
@@ -1575,6 +1581,38 @@ static boolean waitkey(int wait) {
 #endif
 }
 
+#ifdef USE_SDL
+/* sdl12-compat doesn't return sensible values for CTRL+key in keysym.unicode.
+   This is a translation table to provide the same outputs as SDL-1.2.15 */
+uint32 compatkeyfix(SDLKey sym, SDLMod mod) {
+  if ((sym > 64) || (sym < 32)) return (sym & 0x1F);
+  if (mod & KMOD_SHIFT) {
+    switch(sym) {
+      case 32: return 0;
+      case 39: return 0;
+      case 45: return 31;
+      case 54: return 30;
+      case 56: return 127;
+      default: return sym;
+    }
+  } else {
+    switch(sym) {
+      case 32: return 0;
+      case 35: return 30;
+      case 47: return 31;
+      case 50: return 0;
+      case 51: return 27;
+      case 52: return 28;
+      case 53: return 29;
+      case 54: return 30;
+      case 55: return 31;
+      case 56: return 127;
+      default: return sym;
+    }
+  }
+  return sym;
+}
+#endif
 
 /*
 ** 'read_key' reads the next character from the keyboard
@@ -1683,6 +1721,9 @@ int32 read_key(void) {
 //            return ESCAPE;
             default:
               ch = ev.key.keysym.unicode;
+              /* Workaround an sdl12-compat bug */
+              if ((ch == 0) && (ev.key.keysym.mod & KMOD_CTRL)) ch=compatkeyfix(ev.key.keysym.sym, ev.key.keysym.mod);
+              //fprintf(stderr, "keysym.unicode=%d keysym.sym=%d keysym.mod=0x%X\n", ch, ev.key.keysym.sym, ev.key.keysym.mod);
               if (ch < 0x100) {
                 matrixflags.noupdate = 0;
                 return ch;
