@@ -1334,6 +1334,9 @@ static void translate(void) {
   token = tokenbase[source];
   firstitem = TRUE;
   while (token != asc_NUL) {        /* Scan through the tokenised source */
+#ifdef DEBUG
+    if (basicvars.debug_flags.debug) fprintf(stderr, "    translate: token=0x%X\n", token);
+#endif
     if (token == BASIC_TOKEN_STAR)    /* '*' command */
       do_star();
     else if (token>=BASIC_TOKEN_LOWEST)       /* Have found a keyword token */
@@ -1367,6 +1370,11 @@ static void translate(void) {
       do_string();
     else if (token == ' ' || token == asc_TAB)      /* Discard white space characters */
       source++;
+    else if ((token == '?' || token == '!') && (tokenbase[source-1] == ' ')) {
+      store(' ');
+      store(token);
+      source++;
+    }
     else if (token == ':') {    /* Handle statement separators */
       store(':');
       do
@@ -1446,7 +1454,7 @@ static int skiptable [] = {
   LOFFSIZE, LOFFSIZE, LOFFSIZE, LOFFSIZE, LOFFSIZE, LOFFSIZE, 1, LOFFSIZE,	/* 08..0F */
   LOFFSIZE, 0, 0, SMALLSIZE, INTSIZE, 0, 0, FLOATSIZE,			/* 10..17 */
   OFFSIZE+SIZESIZE, OFFSIZE+SIZESIZE, INT64SIZE, -1, -1, -1, LOFFSIZE, LOFFSIZE,	/* 18..1F */
-  -1,  0, -1,  0,  0,  0,  0,  0,					/* 20..27 */
+   0,  0, -1,  0,  0,  0,  0,  0,					/* 20..27 */
    0,  0,  0,  0,  0,  0,  0,  0,					/* 28..2F */
   -1, -1, -1, -1, -1, -1, -1, -1,					/* 30..37 */
   -1, -1,  0,  0,  0,  0,  0,  0,					/* 38..3F */
